==> ZenTaoPMS.17.2.php5.4_5.6.zip: zentaopms/extension/biz/sso/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPp2LYLbbSdAUo24SUhOkVuqLNtLTHLjuL/eL13Z8hU6sSJFR4fqN6vFuKStY3+nunnkMh+x0
qtza0OJLOIU6vrjmSMFa+zZdP7+SFosxpbq+DRmQ1HrsPELJnBLX2cIsQ4PMAIqwMVoXB0DZfvVV
eYAIrZBk75ajDuEOzh+z48Jex4FfJK+fIvMNRA7Qtj+DXDztS3YLDhp+Gdq6t+fRHprIYSRYYAcR
YwaYDpOuiYRAFTkjOhrSrjwak6sPCPvt1/BECxXgTfjzsQn4K2ZjDlA1D+uRtHtwbhFrN38F9rFz
tvtwsrYGczeCuGBDu/mtcYH9mvLe3YOUJDYiO1S3lG9rqx73y7Vn+NRn5Uijr+N/Nvox9PJOc37x
MCvNq97SLZFeCfkdNiIh+Cfb5c8txmkb18cpguyAM7HqJ37jy1Vf2tHaK2ak6TE2yzIoeh95m0dg
EUPgXTeZxNZh0GvvdXn5yFg3we9JGnBsgwJdsdobdngYFroIlicU3rYciITezm==

==> ZenTaoPMS.17.4.php7.0.zip: zentaopms/extension/biz/sso/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPq2981SKLfbOLJsrDFvn/X8NY8k5DwjuwoTfbpsMc3RPeMTmmiNZmzBbNYp/ooGbQJdrjswL
S8R8Tt1U92LDwifUy+kXt9+jr+zoMBiHRuZuaCDItk1kRb7yCXybm9p+G5H8CxFdolrG90DfqTqu
K6LhEjccFLpJAt3xgGnH2uVZD10Zs6caC1D91IoUhhA9zlwICCVBJT3c9JiYXQN2ZBXV6w010q+W
cQBEUih0dIly2rogyR7oODYR4h8qOK4xGr6L57liEdUNpRXXsLFSP+DnEUl8pAr7a8Q+CWXMoR88
zS/ZiYVFi6QDHVpTRsW8GLw/kYvSl4TtwGmhco/L3DMhgsDgs3jOnWEBnhGSZT0KPU7gk5ngWrlG
6tCT01z9D/7Qhqy7EZBIPrcLohilOwBdpLCtA7eMDOD4vKmSayzLl+4KPWJueBFSvvx/6/GmaVZm
gAot2xlkHrH8aL+FE+rB0sE2R14eLTSGCV8diO1oEwQYTfc01icimKugeIs+vXloEnfFIz/Iy2aQ
OjU6XmQf26DLtQTFWuhU8veDNXIeORourU7Qzt3F94ZzNKgB3//0WkxkvTSDJNXFwbrNJQSBtBAK
Hf+WILLndGx89qYRXx1R0YR1pAKUAALj9sigZttTllzYQBpp9KFAMcp8bQmo6oA2NVmZ4WO0wY7T
NrhWRrfhZ78wYk2sW9SMO0mpl/N9DuNcNTkPl/cQ0JDTUkQhGdFNp0==
